@@ -8,7 +8,7 @@ use crate::bind;
 
 use super::scan_code::ScanCode;
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum KeyCode {
     Unknown,
     Return,
