@@ -1,7 +1,10 @@
+//! RLE (Run-Length Encoding) acceleration for a [`Surface`].
+
 use crate::{bind, Sdl};
 
 use super::Surface;
 
+/// A Run-length encoded [`Surface`].
 #[derive(Debug)]
 pub struct Rle<'surface, S: Surface> {
     surface: &'surface mut S,
@@ -16,24 +19,40 @@ impl<'surface, S: Surface> Rle<'surface, S> {
         Self { surface }
     }
 
-    pub fn lock(&'surface self) -> RleLock<'surface, S> {
+    /// Locks the surface and Convert into [`RleLock`].
+    pub fn lock(&'surface mut self) -> RleLock<'surface, S> {
         RleLock::new(self)
     }
 }
 
+/// A locked RLE surface.
 #[derive(Debug)]
 pub struct RleLock<'surface, S: Surface> {
-    src: &'surface Rle<'surface, S>,
+    src: &'surface mut Rle<'surface, S>,
 }
 
 impl<'surface, S: Surface> RleLock<'surface, S> {
-    fn new(src: &'surface Rle<'surface, S>) -> Self {
+    fn new(src: &'surface mut Rle<'surface, S>) -> Self {
         let ret = unsafe { bind::SDL_LockSurface(src.surface.as_ptr().as_ptr()) };
         if ret != 0 {
             Sdl::error_then_panic("failed to lock RLE surface");
         }
         Self { src }
     }
+
+    /// Returns the raw pixels data.
+    pub fn pixels(&self) -> &[u8] {
+        let surface = unsafe { self.src.surface.as_ptr().as_ref() };
+        let len = surface.h as usize * surface.pitch as usize;
+        unsafe { std::slice::from_raw_parts(surface.pixels.cast(), len) }
+    }
+
+    /// Returns the raw pixels data for mutating.
+    pub fn pixels_mut(&mut self) -> &mut [u8] {
+        let surface = unsafe { self.src.surface.as_ptr().as_mut() };
+        let len = surface.h as usize * surface.pitch as usize;
+        unsafe { std::slice::from_raw_parts_mut(surface.pixels.cast(), len) }
+    }
 }
 
 impl<'surface, S: Surface> Surface for RleLock<'surface, S> {
